@@ -1,17 +1,19 @@
 package Perinci::Sub::XCompletionBundle::lcpan;
 
-our $DATE = '2021-01-01'; # DATE
-our $VERSION = '0.002'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 use Log::ger;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-09-02'; # DATE
+our $DIST = 'Perinci-Sub-XCompletionBundle-lcpan'; # DIST
+our $VERSION = '0.003'; # VERSION
+
 sub _connect_lcpan {
     no warnings 'once';
 
-    eval "use App::lcpan 0.32";
+    eval "use App::lcpan 0.32"; ## no critic: BuiltinFunctions::ProhibitStringyEval
     if ($@) {
         log_trace("[_cpanm] App::lcpan not available, skipped ".
                          "trying to complete from CPAN module names");
@@ -59,7 +61,7 @@ Perinci::Sub::XCompletionBundle::lcpan - Completion stuffs using local CPAN data
 
 =head1 VERSION
 
-This document describes version 0.002 of Perinci::Sub::XCompletionBundle::lcpan (from Perl distribution Perinci-Sub-XCompletionBundle-lcpan), released on 2020-01-01.
+This document describes version 0.003 of Perinci::Sub::XCompletionBundle::lcpan (from Perl distribution Perinci-Sub-XCompletionBundle-lcpan), released on 2022-09-02.
 
 =head1 HOMEPAGE
 
@@ -69,14 +71,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-XCompletionBundle-lcpan>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Perinci-Sub-XCompletionBundle-lcpan/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<lcpan> and L<App::lcpan>
@@ -85,11 +79,37 @@ L<lcpan> and L<App::lcpan>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by perlancar@cpan.org.
+This software is copyright (c) 2022 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Sub-XCompletionBundle-lcpan>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
